==> atmsupport-1.2.tar.gz: atmsupport-1.2/ats_sscop/test_sscop.h <==
/*
 * Copyright (c) 2003
 *	Fraunhofer Institute for Open Communication Systems (FhG Fokus).
 * 	All rights reserved.
 *
 * Author: Hartmut Brandt <harti@freebsd.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Begemot: atmsupport/ats_sscop/test_sscop.h,v 1.3 2004/07/08 13:33:31 brandt Exp $
 */

struct sscop_stack {
	void	(*init)(void);
	void	(*debug)(u_int);
	void	(*upper_to_sscop)(u_int, u_int, struct uni_msg *);
	void	(*manage_to_sscop)(u_int, u_int, u_int, struct uni_msg *);
	void	(*lower_to_sscop)(struct uni_msg *);
	void	(*reset)(void);
	void	(*start)(void);
	void	(*setparam)(u_int mask, struct sscop_param *param);
	void	(*getparam)(struct sscop_param *);
};

extern const struct sscop_stack user_stack;
#ifdef HAVE_NETGRAPH
extern const struct sscop_stack kern_stack;
#endif

struct winput {
	struct uni_msg	*msg;
	u_int		sig;
	u_int		arg1;
	u_int		arg2;
	TAILQ_ENTRY(winput) link;
};
TAILQ_HEAD(input_list, winput);

extern struct input_list lower_input_list;
extern struct input_list upper_input_list;
extern struct input_list manage_input_list;

==> atmsupport-1.4.tar.gz: atmsupport-1.4/ats_sscop/test_sscop.h <==
/*
 * Copyright (c) 2003
 *	Fraunhofer Institute for Open Communication Systems (FhG Fokus).
 * 	All rights reserved.
 *
 * Author: Hartmut Brandt <harti@freebsd.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Begemot: atmsupport/ats_sscop/test_sscop.h,v 1.4 2004/08/18 12:50:09 brandt Exp $
 */

struct sscop_stack {
	void	(*init)(void);
	void	(*debug)(u_int);
	void	(*upper_to_sscop)(u_int, u_int, struct uni_msg *);
	void	(*manage_to_sscop)(u_int, u_int, u_int, struct uni_msg *);
	void	(*lower_to_sscop)(struct uni_msg *);
	void	(*reset)(void);
	void	(*start)(void);
	void	(*setparam)(u_int mask, struct sscop_param *param);
	void	(*getparam)(struct sscop_param *);
};

extern const struct sscop_stack user_stack;
#ifdef HAVE_NETGRAPH_H
extern const struct sscop_stack kern_stack;
#endif

struct winput {
	struct uni_msg	*msg;
	u_int		sig;
	u_int		arg1;
	u_int		arg2;
	TAILQ_ENTRY(winput) link;
};
TAILQ_HEAD(input_list, winput);

extern struct input_list lower_input_list;
extern struct input_list upper_input_list;
extern struct input_list manage_input_list;
